@@ -17,9 +17,9 @@ fi
 rpm -ivh kernel-2.6.16-76.55vl4.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20110121.tar.gz ]
+if [ ! -r ccs-patch-1.6.9-20110401.tar.gz ]
 then
-    wget -O ccs-patch-1.6.8-20110121.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20110121.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.6.9-20110401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20110401.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -32,7 +32,7 @@ patch << "EOF" || die "Can't patch spec file."
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
 -%define release 76.55%{_dist_release}
-+%define release 76.55%{_dist_release}_tomoyo_1.6.8p4
++%define release 76.55%{_dist_release}_tomoyo_1.6.9
  
  %define make_target bzImage
  
@@ -60,7 +60,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20110121.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.9-20110401.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
